package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````2!Y```````!``````````)"E````
M`````````$``.``(`$``'``;``8````$````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````!"7````````$)<`````````
M$`````````$````&`````*``````````H$````````"@0```````2`0`````
M```!"0`````````0`````````@````8`````H`````````"@0````````*!`
M`````````@`````````"````````"``````````$````!````!@"````````
M&`)````````8`D```````#@`````````.``````````$`````````%#E=&0$
M````/)8````````\ED```````#R60```````U`````````#4``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$``````````O;&EB97AE8R]L9"UE;&8N<V\N,@`````*````
M!`````$```!$<F%G;VY&;'D```#M*`D`"@````0````@````1')A9V]N1FQY
M`````````````````````````````````````````#T````2````````````
M`````````````$X````2`````````````````````````%0````2````````
M`````````````````%L````2`````````````````````````&,````2````
M`````````````````````&H````2`````````````````````````'(````2
M`````````````````````````)`````2`````````````````````````)H`
M```2`````````````````````````*$````2````````````````````````
M`*8````2`````````````````````````*\````2````````````````````
M`````+T````2`````````````````````````,0````2````````````````
M`````````,X````2`````````````````````````-P````2````````````
M`````````````/$````2``````````````````````````0!```2````````
M`````````````````!,!```2`````````````````````````"L!```2````
M`````````````````````%X!```2`````````````````````````'D!```2
M`````````````````````````($!```2`````````````````````````(T!
M```2`````````````````````````*(!```2````````````````````````
M`*X!```2`````````````````````````+X!```2````````````````````
M`````,\!```2`````````````````````````-8!```2````````````````
M`````````-P!```2`````````````````````````.X!```2````````````
M`````````````/X!```2``````````````````````````,"```2````````
M``````````````````@"```2`````````````````````````!$"```2````
M`````````````````````!<"```2`````````````````````````!P"```2
M`````````````````````````","```2`````````````````````````"H"
M```2`````````````````````````"\"```2````````````````````````
M`#<"```2`````````````````````````#\"```2````````````````````
M`````%$"```2`````````````````````````%D"```6````````````````
M`````````%\"```2`````````````````````````&<"```2````````````
M`````````````'L"```2`````````````````````````(X"```2````````
M`````````````````)4"```2`````````````````````````*X"```2````
M`````````````````````+4"```2`````````````````````````+X"```2
M`````````````````````````,<"```2`````````````````````````,X"
M```2`````````````````````````.\"```2````````````````````````
M`$<#```2`````````````````````````&X#```2````````````````````
M`````)$#```2`````````````````````````)\#```2````````````````
M`````````+D#```@`````````````````````````-,#```@````````````
M`````````````'D#```2````H!E``````````````````/H#```1`!0`"*1`
M```````(`````````&T!```2``P`P#9```````!U`````````($"```2``P`
M$"U````````\!P```````/4#```2``P`T!M```````#L`0```````!0$```2
M``T`B%%``````````````````"D#```2``P`0"=```````#/`0```````#8#
M```2``P`,"=````````#`````````%@#```2``P`4#1```````!O`@``````
M`.\#```2``H`T!=```````````````````8````0`!$`2*1`````````````
M``````$````0`!$``:E``````````````````.,!```2``P`P$U```````"@
M`0```````)P"```2``P`4"Q```````"Q`````````/4"```2``P`P"M`````
M``!J`````````!P#```2``P`$"E````````D`````````(D#```2``P`L"9`
M```````J`````````#H!```2````(!M``````````````````!`#```2``P`
M0"E```````"[`````````!(````0`!$`2*1``````````````````.<````1
M`!0`(*1````````(`````````$L!```2````$!M```````````````````T$
M```2``P`2!Y```````!-`0```````/4!```2``P`8$U```````!4````````
M`*X#```1`!@`X*A````````$``````````4$```1`!@`8*1````````(````
M`````$<"```1`!@`Z*A````````(`````````-0"```2``P`,"Q````````=
M`````````,4!```2``P`8$]```````#U`0```````!X!```1`!@``*E`````
M```!``````````,#```2``P``"I```````"U`0```````!D````1`!@`H*A`
M``````!```````````!?96YD`%]?8G-S7W-T87)T`%]E9&%T80!?7W-T86-K
M7V-H:U]G=6%R9`!$1C0P-"XP`&QI8F,N<V\N.`!?7W-T86-K7V-H:U]F86EL
M`&%B;W)T`&UA;&QO8P!M96UM;W9E`'-T<FQE;@!S=')N8VUP`%]R=&QD7V-A
M;&Q?:6YI=`!$1G!R:79A=&5?,2XP`%]I;FET7W1L<P!M96UC<'D`97AI=`!P
M97)L7W)U;@!097)L7W-Y<U]T97)M`&%T97AI=`!P97)L7V9R964`<&5R;%]D
M97-T<G5C=`!P97)L7W!A<G-E`&UY7W!A<E]P;`!097)L7W-A9F5S>7-M86QL
M;V,`<&5R;%]C;VYS=')U8W0`<&5R;%]A;&QO8P!03%]D;U]U;F1U;7``<'1H
M<F5A9%]A=&9O<FL`4&5R;%]A=&9O<FM?;&]C:P!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S>7-?:6YI=#,`<&%R7V-L96%N=7``<W1R;F-P>0!097)L7VUG
M7W-E=`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V=E=%]S=@!097)L7V=V
M7V9E=&-H<'8`<W1R=&]K`'-H85]F:6YA;`!S=')C;7``8VQO<V4`<W1R8VAR
M`'-H85]U<&1A=&4`<W1R9'5P`'-H85]I;FET`&9R964`<F5A9`!C;&]S961I
M<@!L<V5E:P!S=&%T`&=E='!I9`!U;FQI;FL`;W!E;@!R96%D9&ER`&9P<FEN
M=&8`<W!R:6YT9@!?7W-T9&5R<G``<F5A;&QO8P!E<G)N;P!O<&5N9&ER`'!T
M:')E861?9V5T<W!E8VEF:6,`;6MD:7(`<&%R7VUK=&UP9&ER`'-T<G-T<@!M
M96UC:'(`<&%R7W-E='5P7VQI8G!A=&@`86-C97-S`&=E='!W=6ED`')E861L
M:6YK`&=E='5I9`!R;61I<@!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!L
M<W1A=`!P87)?96YV7V-L96%N`'!A<E]I;FET7V5N=@!P87)?9&ER;F%M90!P
M87)?8F%S96YA;64`<&%R7V9I;F1P<F]G`'!A<E]C=7)R96YT7V5X96,`4&5R
M;%]N97=84U]F;&%G<P!84U]);G1E<FYA;'-?4$%27T)/3U0`4&5R;%]N97=8
M4P!B;V]T7T1Y;F%,;V%D97(`>'-?:6YI=`!097)L7W-V7W-E='!V`%!E<FQ?
M<W9?<V5T<'9N`%!,7W1H<E]K97D`7TE435]R96=I<W1E<E1-0VQO;F5486)L
M90!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7VEN:70`;6%I;@!?7W!R
M;V=N86UE`&5N=FER;VX`7W-T87)T`%]F:6YI`&QI8G!E<FPN<V\N-2XS,@!L
M:6)P=&AR96%D+G-O+C``;&EB9&PN<V\N,`!L:6)M+G-O+C0`;&EB8W)Y<'0N
M<V\N-`!L:6)U=&EL+G-O+C0`+W5S<B]L:6(O9V-C.#`Z+W5S<B]L;V-A;"]L
M:6(O<&5R;#4O-2XS,B]M86-H+T-/4D4`````$0```#X````$````"````"`<
M$``%0`2`*`!`!)"&`8S"(0$@20`$&XB".$&Z!`((/@```$````!$````2```
M`$D```!/````4````%$```!3````5````%4```!6````6````%H```!;````
M`````%T```!Z\$IKO5!VGF[%WQ_.WD<M:G^:?.O3[PX@_^0.+L6;MM1DU'RY
MC?$.V7%8'+KCDGQ"^M>'^J%L8+(!BV_B1\8!P^4_+(?YG(%GK\QF0D75[(D'
M<-/)U;)Q,V+;[16,)<Q6I)N6I]VC:^85`X-_J9R;:QJ>4`J*$%>CX/M)(6)D
M!P```@`"``(``@`"``(``P`#``(``@```````@`````````````````"````
M`@````````````(``@`"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"
M``(``@`"``(``@`"``(``@`"``(``@````````````````````$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$````!``$``0````$``0`!``$``@`!
M``$``0`!``(``0`"`#,````0`````````%`WEP@```(`*P```!````"0M'X`
M```#`((``````````*)````````2````+```````````````X*A````````%
M````5@``````````````Z*A````````%````6````````````````*E`````
M```%````6P``````````````H*A````````%````70``````````````(*)`
M```````'`````@``````````````**)````````'````"```````````````
M,*)````````'````!P``````````````.*)````````'````#0``````````
M````0*)````````'````"@``````````````2*)````````'````!@``````
M````````4*)````````'`````0``````````````6*)````````'````!0``
M````````````8*)````````'`````P``````````````:*)````````'````
M!```````````````<*)````````'````*P``````````````>*)````````'
M````+0``````````````@*)````````'````*```````````````B*)`````
M```'````*@``````````````D*)````````'````)```````````````F*)`
M```````'````)@``````````````H*)````````'````(```````````````
MJ*)````````'````(@``````````````L*)````````'````-@``````````
M````N*)````````'````-P``````````````P*)````````'````,@``````
M````````R*)````````'````-```````````````T*)````````'````,0``
M````````````V*)````````'````+@``````````````X*)````````'````
M.P``````````````Z*)````````'````.@``````````````\*)````````'
M````/@``````````````^*)````````'````'@```````````````*-`````
M```'````'P``````````````"*-````````'````&P``````````````$*-`
M```````'````'```````````````&*-````````'````%@``````````````
M(*-````````'````-0``````````````**-````````'````,P``````````
M````,*-````````'````,```````````````.*-````````'````+P``````
M````````0*-````````'````*0``````````````2*-````````'````)P``
M````````````4*-````````'````)0``````````````6*-````````'````
M(P``````````````8*-````````'````(0``````````````:*-````````'
M````'0``````````````<*-````````'````&@``````````````>*-`````
M```'````&0``````````````@*-````````'````&```````````````B*-`
M```````'````%P``````````````D*-````````'````.0``````````````
MF*-````````'````.```````````````H*-````````'````%0``````````
M````J*-````````'````4P``````````````L*-````````'````3P``````
M````````N*-````````'````%```````````````P*-````````'````$P``
M````````````R*-````````'````$@``````````````T*-````````'````
M$0``````````````V*-````````'````$```````````````X*-````````'
M````#P``````````````Z*-````````'````#@``````````````\*-`````
M```'````#```````````````^*-````````'````"P```````````````*1`
M```````'````"0``````````````2(/L".A["```Z'<Y``!(@\0(PP``````
M``````````#_-1J*``#_)1R*``"0D)"0_R4:B@``:`````#IX/____\E$HH`
M`&@!````Z=#_____)0J*``!H`@```.G`_____R4"B@``:`,```#IL/____\E
M^HD``&@$````Z:#_____)?*)``!H!0```.F0_____R7JB0``:`8```#I@/__
M__\EXHD``&@'````Z7#_____)=J)``!H"````.E@_____R72B0``:`D```#I
M4/____\ERHD``&@*````Z4#_____)<*)``!H"P```.DP_____R6ZB0``:`P`
M``#I(/____\ELHD``&@-````Z1#_____):J)``!H#@```.D`_____R6BB0``
M:`\```#I\/[___\EFHD``&@0````Z>#^____)9*)``!H$0```.G0_O___R6*
MB0``:!(```#IP/[___\E@HD``&@3````Z;#^____)7J)``!H%````.F@_O__
M_R5RB0``:!4```#ID/[___\E:HD``&@6````Z8#^____)6*)``!H%P```.EP
M_O___R5:B0``:!@```#I8/[___\E4HD``&@9````Z5#^____)4J)``!H&@``
M`.E`_O___R5"B0``:!L```#I,/[___\E.HD``&@<````Z2#^____)3*)``!H
M'0```.D0_O___R4JB0``:!X```#I`/[___\E(HD``&@?````Z?#]____)1J)
M``!H(````.G@_?___R42B0``:"$```#IT/W___\E"HD``&@B````Z<#]____
M)0*)``!H(P```.FP_?___R7ZB```:"0```#IH/W___\E\H@``&@E````Z9#]
M____)>J(``!H)@```.F`_?___R7BB```:"<```#I</W___\EVH@``&@H````
MZ6#]____)=*(``!H*0```.E0_?___R7*B```:"H```#I0/W___\EPH@``&@K
M````Z3#]____);J(``!H+````.D@_?___R6RB```:"T```#I$/W___\EJH@`
M`&@N````Z0#]____):*(``!H+P```.GP_/___R6:B```:#````#IX/S___\E
MDH@``&@Q````Z=#\____)8J(``!H,@```.G`_/___R6"B```:#,```#IL/S_
M__\E>H@``&@T````Z:#\____)7*(``!H-0```.F0_/___R5JB```:#8```#I
M@/S___\E8H@``&@W````Z7#\____)5J(``!H.````.E@_/___R52B```:#D`
M``#I4/S___\E2H@``&@Z````Z4#\____)4*(``!H.P```.DP_/___R4ZB```
M:#P```#I(/S__U-(@^PP2(L%Q(P``$B)1"0H,<")?"0<2(U\)!Q(B70D$$B-
M="002(E4)`A(C50D".C[_O__NA`;0`"_(!M``$B)UN@9____@#WBC````'4O
MZ!O___](B05LC```2(7`#X1X`0``2(G'Z!/___^+/9V,``#H*/W__\:`$0D`
M``"+/8N,``#H%OW__XL]@(P``("(P@,```+H!/W__X"(P@,```&+1"0<C7@$
MC5@#2&/_2,'G`^C7_O__2(M\)!!$BT0D'$B)!?:+``!(BQ=(QT`(=U-``$C'
M0!AZ4T``2(D02(L5:8<``$B)4!!!@_@!#X[=````2(/'"$&#P`.^!````$R+
M#TACUH/&`4B#QPA,B0S003GP=>I-8\!)P>`#2L<$``````!(BSV:BP``B=I%
M,<!(B<&^X"9``.A@_O__B<.%P'1)2(L]>XL``.A>_O__,<!(C70D)+\Z4D``
MZ#T#``!(A<!T-TB+/5F+``#H3/[__^A7_O__B=A(BTPD*$@S#4F+``!U7DB#
MQ#!;PTB+/3*+``#H1?[__XG#ZZ=(BST2BP``2(7_=`?H0!D``.NVO^A10`!(
MC70D).C?`@``2(G'2(D%[8H``$B%P'28Z]E!N"````#I0O___[\!````Z(GZ
M___HI/K__[@`````2#T`````<SI52(GE0513@STQXK__)74@2(G#3(LC_U,0
M28D$)$B#PQA(@?L`````<PN#>P@E=./H`OK__UM!7%W#PU5(B>532(/L"+@`
M````2"T`````2,'X`TB)PW41Z&(S``!(@\0(6UW#2(7;=.](@^L!2(L$W0``
M``!(@_@!=NG_T.OE54B)Y4%7059!54%44TB#[!A(B?-,BR]%B>],C7<(26/%
M3(UDQQ!(@SWJA0```'17187M?A=(BT<(2(7`=`Y(B05[A0``#[80A-)U3^AW
M^?__Z(+Y__^X`*!``$B%P'1-2(G?Z(#Y__^X`*!``$B%P'1"3(GB3(GV1(GO
MZ`C]__^)Q^AQ^?__3(DEBH4``.N@2(/``0^V$(32=+&`^B]U\$B-4`%(B145
MA0``Z^/HPO[__^NTOP0>0`#H*OG__[@`````2"T`````2,'X`TB)1<AT++L`
M````ZPI(@\,!2#E=R'0;2(L$W0````!(@_@!=NA,B>),B?9$B?__T.O;Z(3X
M__^X`````$@M`````$C!^`-(B47(#X15____NP````#K#DB#PP%(.5W(#X1`
M____2(L$W0````!(@_@!=N1,B>),B?9$B?__T.O7N$BD0`!(/4BD0`!T%[@`
M````2(7`=`U52(GEOTBD0`#_T%W#P[Y(I$``2('N2*1``$C!_@-(B?!(P>@_
M2`'&2-'^=!>X`````$B%P'0-54B)Y;](I$``_]!=P\.`/7"$````=5E52(GE
M0513NT"D0`!(@>LXI$``2,'[`TB#ZP%!O#BD0`!(BP5.A```2#G8<QM(@\`!
M2(D%/H0``$'_%,1(BP4SA```2#G8<N7H3O___\8%&H0```%;05Q=P\-52(GE
MZ%W___]=PV9F9F8N#Q^$````````````05=!5D%505154TB#[`A(A?\/A*L`
M``!,BSW2@P``387_#X2;````#[8'A,!T!#P]=5Y%,>1)BQ](A=MT.4F)]4F)
M_DUCY$R)_0\?@`````!,B>),B?9(B=_H@O?__X7`=0="@#PC/71'2(/%"$B+
M70!(A=MUVDB#Q`A(B=A;74%<05U!7D%?PP\?A```````28G\28/$`4$/M@0D
MA,!T!#P]=>]!*?SKC`\?@`````!,*?U*C5PC`4C!_0-!B6T`Z[0QV^NP9BX/
M'X0``````%-(B?M(@^P02(L%48<``$B)1"0(,<!F+@\?A```````,<!(C70D
M!$B)W^@!____2(7`="Y(8U0D!$B+!>""``!(C0302(M0"$B)$$B%TG302(/`
M"$B+4`A(B1!(A=)U\.N^2(M$)`A(,P7RA@``=09(@\006\/HI?;__P\?1```
M05=!5D%505152(GU4TB)^TB#["A(BP7%A@``2(E$)!@QP#'`@#X]#Y3`2`'%
M2(GOZ'OV__](C70D%$B)WTF)Q#'`Z&G^__](A<`/A`0!``!(B<=)B<7H5?;_
M_TPYX`^#T````$QC="042<'F`P^V`X3`#X2<`0``/#T/A)0!``!(B=A(@\`!
M#[80A-)T!8#Z/77P2"G82)A*C7P@`DP#-?R!``#H%_;__TF)!DB%P`^$<P$`
M`$B+!>2!``!(8U0D%$B-2P%(BQ30#[8#B`*$P'0D/#UU#NL>#Q^$``````"$
MP'022(/!`0^V0?](@\(!B`(\/77JQ@(],<`/'T0```^V3`4`B$P"`4B#P`&$
MR77O,<!(BUPD&$@S'<&%```/A0T!``!(@\0H6UU!7$%=05Y!7\,QP&8N#Q^$
M```````/ME0%`$&(5`4`2(/``832=>[KO4R+/46!``!)@S\`#X2V````3(GX
M,=+K!P\?0`!$B>I(@\`(1(UJ`4B#.`!U[XUR`TAC]DC!Y@.+!2^%``"%P'5;
MQP4AA0```0```$B)]^@9]?__2(7`='Q-8\5,B?Y(B<=.C33%`````$R)1"0(
M3(GRZ`;U__],BT0D"$B)!<J```!(B<%*QT3!"`````!$B6PD%.F!_O__#Q]`
M`$R)_^CH]/__2(G!2(D%GH```$B%P'0A36/%3HTTQ0````#KQ3'`Z7W^__^^
M$````$4Q[>EC____N/_____IX?[__^AI]/__9@\?A```````055!5%532('L
MF````$B+!8R$``!(B80DB````#'`2(7_=`B`/P!(B?UU)4B+A"2(````2#,%
M9H0```^%_````$B!Q)@```!;74%<05W#9I#H6_3__TF)Q$B%P'3.3(GGZ%OT
M__](A<`/A+(```!(C5@0OYE10`"Y`@```$B)WO.F#Y?`'`"$P'33OYM10`"Y
M`P```$B)WO.F#Y?`'`"$P'2[2(GOZ,;S__](B=])B<7HN_/__T&-?`4"2&/_
MZ+[S__](B=E(B>J^GE%``$F)Q4B)QS'`Z/;S__],B>](B>;H^_/__TR)[X/X
M_W0/#[=$)!!F)0#P9CT`0'0YZ._S__],B>_H]_/__TR)Y^BO\___2(7`#X54
M____9@\?1```3(GGZ.CS__](B>_H\//__^GV_O__Z,;^___KQ>@?\___9F8N
M#Q^$```````/'T``4TB)^TB![)````!(BP4^@P``2(F$)(@````QP$B)YNB\
M\___A<!U.`^W5"00@>(`\```@?H`0```=`B!^@"@``!U'[X"````2(G?Z*#S
M__^%P`^4P`^VP.L(9@\?1```,<!(BXPDB````$@S#=^"``!U"4B!Q)````!;
MP^B/\O__9F8N#Q^$```````/'T``056Z_P,``$F)]4%454B)_;^D44``4TB!
M[!@$``!(BP6<@@``2(F$)`@$```QP$B)YN@Z\___A<!^:XU0_T2+);R"``!(
M8]J`/!P`=5.%TG1;2(G:OB\```!(B>?H'_/__TB%P'1&1(GGZ"+S__](B=E(
MB>)(B>Y(B<?H(?/__TB+A"0(!```2#,%,H(``'4T2('$&`0``%M=05Q!7<-F
MD$ACV.NL1(LE5((``$2)Y^C<\O__3(GJ2(GN2(G'Z.[R___KN^BW\?__#Q^`
M`````$B#[`B+/2:"``#HL?+__[FH4T``NJ`90`"^MU%``$B)QTB#Q`CI!O3_
M_V8/'T0``$B#[`B+/?:!``#H@?+__TB)Q^BY____BSWC@0``Z&[R__]!N)A1
M0`!%,<FZ4#1``$R)P;[344``2(G'2(/$".G,\___9F8N#Q^$``````"0,<##
M9F8N#Q^$``````!FD$%5051)B?R_Z%%``%532(GS2('LF`0``$B+!4&!``!(
MB80DB`0``#'`2(GFZ/_X__^^+P```$R)YTB)Q>@O\O__2(7`=#I,B>:_\5%`
M`#'`Z"OZ__],B>!(B[0DB`0``$@S-?F````/A5T!``!(@<28!```6UU!7$%=
MPP\?1```3(GGZ*CP__](B=]!B<7H[?'__[[^44``2(G'Z/#Q__](B<-(A=MT
MGH`[``^$KP```$B%[70/2(G>2(GOZ-_Q__^%P'1^2(G?Z&/P__^)P4B8@'P#
M_R]U&0\?A```````@^D!2&/1@'P3_R_&!!,`=.]!C40-`3W_`P``#X]%____
MO@)20``QP$V)X+D`4D``2(V\)(````!(B=KH</#__TB)YDB-O"2`````Z'#P
M__^%P'4/#[=$)!!F)0#P9CT`@'1-OOY10``Q_^A!\?__2(G#Z4S___]F#Q^$
M``````!(A>UT&[D"````OYE10`!(B>[SI@^7P!P`A,!TQ@\?`+N944``N0$`
M``#I8O___Y"^`0```$B-O"2`````Z%[P__^%P'6=2(VT)(````"_\5%``.C(
M^/__2(V\)(````#HN_#__^F._O__Z%'O__^0#[872(GXA-)T&68/'T0``$B#
MQP&`^B\/MA=(#T3'A-)U[L/#9F8N#Q^$``````"02(7_#X27````@#\`#X2.
M````4TB)^^@5[___2(U4`_](.=-R%.LG9@\?A```````2(/J`4@YTW0:@#HO
M=/+K!8`Z+W0C2(/J`4@YTW+R2#G3=16`.B]T6+\`4D``6^D=\/__@#HO=0E(
M@^H!2#G3<O)(*=HQP$B-2@)(@?D`!```=Q9(@\(!2(G>OX"D0`#H'/#__[B`
MI$``6\,/'T0``+^944``Z=;O__]F#Q]$``"_F5%``%OIQ>___P\?1```2(/L
M2/,/;P5T*0``OPE20`#S#V\-=RD``$B+!8!^``!(B40D.#'`#[<%<BD```\I
M1"009HE$)#`QP`\I3"0@Z/SV__\QP+\24D``Z/#V__\QP+\:4D``Z.3V__\Q
MP+\C4D``Z-CV__\QP+\J4D``Z,SV__\QP+\Z4D``Z,#V__\QP+_H44``Z+3V
M__\QP+]&4D``Z*CV__\QP+]04D``Z)SV__\QP+]:4D``Z)#V__\QP+_Q44``
MZ(3V__\QP$B-="0,OV120`#HH_7__TB%P'0/2(G&OU!20``QP.C?]O__,<!(
MC70D#+]U4D``Z'[U__](A<!T#TB)QK^'4D``,<#HNO;__S'`2(UT)`R_DE)`
M`.A9]?__2(7`=#1(B<:_Z%%``#'`Z)7V__\QP+Z^4D``ORI20`#HA/;__TB+
M1"0X2#,%6'T``'5F2(/$2,.0,<!(C70D#+^B4D``Z`_U__](A<!T&DB)QK]&
M4D``,<#H2_;__^NT9@\?A```````2(UT)"&_LU)``+D*````\Z8/E\`<`(3`
M=9%(C70D*[]&4D``,<#H%?;__^E[____Z*OL__]F9BX/'X0``````$B#[!A(
MBP75?```2(E$)`@QP(L%0'@``(/X_W032(MT)`A(,S6W?```=3I(@\08PTB-
M="0$OT920``QP.AO]/__2(G",<!(A=)T$@^V$H#Z,`^5P3'`A-(/E<`AR(D%
M]7<``.NXZ#;L__]F#Q]$``!(@^P(Z,?M__^)Q^C0[?__2(7`=`-(BP!(@\0(
MPP\?`$%454B)_;_`4D``4TB#[!!(BP4Y?```2(E$)`@QP$B-="0$Z/CS__](
MB>Y(A<!T"(`X`$B)PW4HO\!20``QP.@L]?__2(M$)`A(,P4`?```=5I(@\00
M6UU!7,,/'T0``$B)Q^AH[?__2(7`===(B>_HJ^O__TB)WTF)Q.B@Z___28U\
M!`+HINO__[X"4D``28G82(GJ28G$2(G'N?Y10``QP.C9Z___3(GFZXSH7^O_
M_V9F+@\?A```````#Q]``$%6055)B?V_Z%%``$%455-(@>Q@@0``2(L%<GL`
M`$B)A"18@0``,<!(C70D$$C'A"20````W%)``$C'A"28````F5%``$C'A"2@
M`````````$C'A"30````AU)``$C'A"38````XE)``$C'A"3@````Z5)``$C'
MA"3H````\5)``$C'A"3P````]E)``$C'A"3X`````````$C'A"2P````T%)`
M`$C'A"2X````^E)``$C'A"3``````````.B>\O__2(7`=`F`.``/A6`$```Q
MP.A)_O__2(G#2(7`#X3=`P``2(G?Z'7J__](C7P``>A[ZO__@#L`28G$="),
MB>4/MA-(B>\QP+X#4T``2(/#`4B#Q0+HINK__X`[`'7A2(V<)-@```"_AU)`
M`.L39I!(@\,(2(M[^$B%_P^$<P$``$B-="00,<#H$_+__TB)Q4B%P'3;@#@`
M=-9(B<?HWO;__X7`=,I(B>_H0NO__TB)PTB%P`^$.@$``&8/'T0``$B)WHL6
M2(/&!(V"__[^_O?2(=`E@("`@'3IB<+!ZA"I@(````]$PDB-5@)(#T3RB<$`
MP4R)X4B#W@-(*=Z+.4B#P02-A__^_O[WUR'X)8"`@(!TZ8G"P>H0J8"````/
M1,)(C5$"2`]$RHG"`,)(@]D#3"GAC:P.!`0``$AC[4B)[^AJZ?__O@U30`!-
MB>%(B=I(B<=)B<9!N`A30``QP+D`4D``Z)?I__^^P`$``$R)]^CJZO__@_C_
M=1YD2(L4)0````!(BP6E<@``1(L$`D&#^!$/A;4"``!(C70D$$R)]^BZZ?__
MB<.%P`^$L````$F+50!(BSU=>0``3(GQ,<"^`%1``#'MZ*3J__](BXPD6($`
M`$@S#?5X``!(B>@/A9,$``!(@<1@@0``6UU!7$%=05[#,>UF+@\?A```````
M2&/%2(N<Q)````!(A=MT0(`[`'0[2(G?@\4!Z&#U__^%P'3<2(G?Z,3I__](
MB<-(A<`/A8C^__](8\5(BYS$D````$B%VW7(#Q^$```````QV^EI_O__9@\?
MA```````#[=$)"!F)0#P9CT`0`^%/?___T2+9"0DZ+/I__]!.<0/A2K___\/
MMT0D(&8E_P%F/<`!#X47____2(GOZ`_H__](C70D$+\64T``2(G%,<#HZ^__
M_TB%P`^$\@$``$F+?0!(B<;HIO;__TF)Q$B%P`^$V@$``$R)Y^C"Y___@_@#
M?CU(8]"_&U-``+D%````28UT%/SSI@^7PH#:`(32=1^#^`0/A+D"``"#Z`1(
MF$&`?`3_+P^$J`(```\?1```,<#HR?K__X7`=15,B><Q]NA+Z?__08G$A<`/
MA7D!``"^OE)``+]&4D``,<#HG_#__^@ZZ?__N0!20`!,B?)(B>]!B<!!N9A1
M0`"^-%-``#'`Z(KG___K3@\?A```````9$B+%"4`````2(L%H'```(,\`A%U
M0NCUZ/__2(/L"(/#`4R)\FB844``08G`08G9N0!20`"^0E-``$B)[S'`Z#SG
M__]86K[``0``2(GOZ(WH__^#^/]TJ$R)]^A0Y___2(GNO^A10``QP.@!\/__
M2(GOZ(GZ___IT/W__P\?0`"_T%)``#'MZQ(/'X``````2&/%2(N\Q+````!(
MA?]T<DB-="00,<"#Q0'H<>[__TB%P'3<@#@`=-=(B<?HK^?__TB)PTB%P'3'
MZ=7[__])BU4`2(L]OW8``$R)\3'`OKA30``Q[>@&Z/__Z5W]__^02(G'2(E$
M)`CH`_K__TB+1"0(2(G'Z&;G__](B<7I.OW__[\-````N]520`#H#^;__TF)
MQ.F4^___#Q^``````$V+90#I'?[__[H"````2,?&[O___XG'Z-3G__^Z!@``
M`$B-M"10`0``1(GGZ,_G__^`O"10`0```'4.@+PD40$``$,/A`H!```QTC'V
M1(GGZ)OG__\QP.B$&@``2(G#ZQ*)PDB-M"10`0``2(G?Z,T:``"Z`(```$B-
MM"10`0``1(GGZ'CG__^%P'_51(GG3(VD)``!``#H=.?__TB)WDB-O"0``0``
M2(V<)"`!``#H+!P``$R-:R@/'X0``````$$/MA0D2(G?O@-30``QP$B#PP))
M@\0!Z'3E__]).=UUW\:$)$@!````0;F844``3(V$)"`!``"Y`%)``$R)\KXE
M4T``2(GO,<#H0N7__^D5_O__38MM"$V%[0^$4/W__TR)[^C(Y/__2(/X`P^&
M/OW__TF-=`7\OR!30`"Y!0```/.F#Y?`'`"$P$T/1.7I'?W__X"\)%(!``!!
M#X7H_O__@+PD4P$``$,/A=K^__^`O"14`0``2`^%S/[__X"\)%4!``!%#X6^
M_O__N@(```!(Q\;&____1(GGZ%'F__^Z*0```$B-M"10`0``1(GGZ$SF__]!
MN9A10`!,C80D4`$``.DP____Z!3D__\/'T``55-(@^P8BSV$=```2(L%/70`
M`$B)1"0(,<#H`>7__XL]:W0``$B)P^CSY/__2(UT)`2_*E)```^VD[@```"(
MD+D````QP.C5Z___2(7`=`F`.#$/A)<!```QP.A0]?__BSTJ=```Z+7D__^Y
M`P```+H!````OE-30`!(B<?HSN7__TB)PTB%P'0S2(M`$(L]_',``$B+*.B$
MY/__NE530`!(B<=(B>[HE.3__TB+0Q!(BQCV0PY`#X5S`0``BSW-<P``Z%CD
M__^Y`P```+H!````OEI30`!(B<?H<>7__TB)PTB%P'0]2(UT)`2_\5%``#'`
MZ"CK__](B<5(A<`/A/P```!(BT,0BSV"<P``2(L8Z`KD__](B>I(B=Y(B<?H
M'.3__XL]9G,``.CQX___N@$```"^7%-``$B)Q^@?Y?__BSU)<P``2(G#Z-'C
M__^Z<5-``$B)WDB)Q^CAX___BSTK<P``Z+;C__](C70D!+_H44``QH"Y````
M`#'`Z)[J__](B06O<@``2(7`=#>^P`$``$B)Q^A%Y/__C5`!@_H!=@F#^!$/
MA9\```!(BT0D"$@S!9AR```/A:P```!(@\086UW#2(L]='(``.CO]O__2(D%
M8'(``$B%P'6QOUA40`#HB>3__V8/'X0``````(!X`0`/A&;^___I6O[__Y!(
MBP4Y<@``BSV#<@``2(LH2(M#$$B+&.@$X___2(GN2(G?Z&GO___I^/[__P\?
M0`"+/5IR``#HY>+__TB)WDB)Q^@ZY/__Z7+^__^)P4B+!>QQ``!(BQ7=<0``
MOX!40`!(BS`QP.@&Y/__Z*'A__^054B)_5-(@^P(Z'+R__\/MA!(B<.$TG0:
M#Q^$``````!(@\`!@/HO#[802`]$V(32=>XQP.C']/__2(7M="*%P'0>@'T`
M`'08OPA30`"Y!````$B)WO.F#Y?`'`"$P'0'2(/$"%M=PTB#Q`A(B>];7>G+
M[/__9F8N#Q^$```````/'T``````````````````05=,C4\X059!54%455-(
M@>R8`@``2(L%-'$``$B)A"2(`@``,<!(B>),C9*`````28G008L!28LQ28/`
M$$F#P0@/R(G`2(GQ28E`\$B)\$C!Z2!(P>@H2,'N."4`_P``2`GP2(G.2,'A
M"$C!YAB!X0``_P")]D@)\$@)R$F)0/A-.<)UKDB-L@`"```/'T``2(M":$@S
M0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?)UU4R+%TB+7Q!(
MBW<@2(MO&$R)T$R)TDR+3PA(P>H;2,'@!4@)T`,$)(V4,)EY@EI(B=A(BW0D
M"$@QZ$PAR$B-M#69>8):2#'H1(TL`DR)RDR)R$C!Z`)(P>(>38GH2`G"2(G8
M2<'H&XG12#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,B=9,B=!(P>8>2,'H
M`DV)XT@)\$B+="002<'K&T@QPD&)P$PAZDB-M#.9>8):2#'*2`'R3(GF2,'F
M!4P)WD2-'!9,B>Y)P>T"2(M4)!A(P>8>3`GN2(V4$9EY@EI,B=E(,?!!B?9,
M(>!,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)(P>$>1(TL`DB)\$B+5"0@
M3`GA3(GN2#'(28V4$)EY@EI(P>X;08G,3"'83#'P2`'03(GJ2,'B!4@)\D2-
M!`),B=I)P>L"2(M$)"A(P>(>3(G&3`G:28V$!IEY@EI(P>X;2#'108G33"'I
M3#'A2`'!3(G`2,'@!4@)\$2--`A,B>A)P>T"2(M,)#!(P>`>3(GV3`GH28V,
M#)EY@EI(,<)!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)\4R)QDG!Z`)(P>8>
M1(TD$4B+5"0X3`G&3(GA2#'P28V4$YEY@EI(P>D;08GP3"'P3#'H2`'03(GB
M2,'B!4@)RDR)\4G![@)(P>$>1(T<`DB)\$B+5"1`3`GQ3(G>2#'(28V4%9EY
M@EI(P>X;08G.3"'@3#'`2`'03(G:2,'B!4@)\D2-+`),B>))P>P"2(M$)$A(
MP>(>3(GN3`GB28V$`)EY@EI(P>X;2#'108G43"'93#'Q2`'!3(GH2,'@!4@)
M\$2-!`A,B=A)P>L"2(M,)%!(P>`>3(G&3`G828V,#IEY@EI(P>X;2#'"08G#
M3"'J3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)(P>8>1(TT$4B+5"183`GN3(GQ
M2#'P28V4%)EY@EI(P>D;08GU3"'`3#'82`'03(GR2,'B!4@)RDR)P4G!Z`)(
MP>$>1(TD`DB)\$B+5"1@3`G!3(GF2#'(28V4$YEY@EI(P>X;08G(3"'P3#'H
M2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"3(G>3`GR28V$!9EY
M@EI(P>X;2#'108G63"'A3#'!2`'!3(G82,'@!4@)\$2-+`A,B>!)P>P"2(M,
M)'!(P>`>3(GN3`G@28V,")EY@EI(P>X;2#'"08G$3"':3#'R2`'*3(GI2,'A
M!4@)\4R)WDG!ZP)(P>8>1(T$$4B+5"1X3`G>3(G!2#'P28V4%IEY@EI(P>D;
M08GS3"'H3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)(P>$>1(TT`DB)\$B+E"2`
M````3`GI3(GV2#'(28V4%)EY@EI(P>X;08G-3"'`3#'82`'03(GR2,'B!4@)
M\D2-)`),B<))P>@"2(N$)(@```!(P>(>3(GF3`G"28V$`YEY@EI(P>X;2#'1
M08G03"'Q3#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<"$R)\$G![@)(P>`>
M28VT-9EY@EI-B=U,"?!)P>T;2#'"B<%,(>),,<)(`?),B=Y(P>8%3`GNB?9(
M`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'83XV$()EY@EI-B>Q(
M,<A)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))P>`>08G$30G828GS
MB?9(`[0DJ````$TQPT0QVDR+G"2@````2HV,&:'KV6Y-B>-(`=%,B>))P>L;
M2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0DL````$DQ
MU40QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>
M08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BAZ]EN3(GI2<'L&TC!
MX05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9(`[0DP````$DQRT0Q
MV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)Z$G![0)(P>`>08G3
M3`GH28G-B<E(`XPDR````$DQQ44QZ$V)W4Z-A`:AZ]EN3(G>2<'M&TC!Y@5,
M">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$,>)-B>Q(C8P1H>O9
M;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!ZP)(P>(>08G,3`G:
M38G#18G`3`.$)-@```!),=-$,=Y-B>-(C;0PH>O9;DR)X$G!ZQM(P>`%3`G8
MB<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G22`.4).````!),?5$,>E-B=U-
MC80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"2,'A'D6)Q4P)X4F)
M](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'"3(G82<'K
M`D@#M"3H````2,'@'D&)U$P)V$F)RXG)2`.,)/````!),<-%,=A-B>-.C80&
MH>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@'D&)\TT)Z$F)Q8G`
M2`.$)/@```!-,<5$,>I-B=U(C8P1H>O9;DR)VDG![1M(P>(%3`GJB=)(`=%,
MB>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-M#"AZ]EN3(GH2<'L
M&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"08G$3`.$)``!``!,"=Y)B=.)TD@#
ME"0(`0``23'S1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A!4P)V8G)20'(3(GI
M2<'M`DC!X1Y%B<-,">E)B?6)]D@#M"00`0``23'-1#'H38G=2(V4`J'KV6Y,
MB=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,">!)B<R)R4DQQ$4Q
MX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)V$G!ZP))P>`>08GT
M30G828G#2`.,)!@!``")P$TQPT@#A"0@`0``1#':38GC2(V,$:'KV6Y,B>))
MP>L;2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0D*`$`
M`$DQU40Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(
MP>8>08G%3`GF28G4B=)(`Y0D,`$``$DQ]$0QX4V)[$V-A`BAZ]EN3(GI2<'L
M&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9),<M$,=A-B>-(
M`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P03(GH2<'M`DC!X!Y,
M">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[DR+K"1`
M`0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G02"'P32'<20G$N-R\
M&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!S$R)V4G!ZP)(P>$>
M3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-B>5)`=!,B>))P>T;
M2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)T4TAQDPAX4P)\4R+
MM"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$C30.3(GF2<'L`DC!
MYAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$30'C38GT3`':38GS
M2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$B=I,"=Y)(=5,(?9,
M">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%30GH18TL,$V)\$G!
M[@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!``!)`<9,`?%-B>Y)
M`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)X4F)]$&)RTD)R$TA
MZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L&TC!X@5,">)&C20"
M3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,BZPD>`$``$D!Q4P!
M[DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(P>8>3`GV38G&B?%(
M"?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)ZTG!XP5)P>X;30GS
M18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N3`GF3(ND)(@!``!)
M`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)P>T"2<'@'DT)Z$F)
MU42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE20'+3(GA2<'M&TC!
MX05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-(=Y-(>!-"?!,B[0D
MF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT`DR)XDG![`)(P>(>
M3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,`>9-B?1(`?%,B?9)
MP>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ2`GR22'-3"'R3`GJ
M3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)ZT6-+!--B?-)P>X"
M2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``20'&30'P38GN3`'&
M38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)B=1$B<9-"<-)(?1-
M(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(P>$%3`GA1HTD&4R)
MZ4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL),`!``!)`<5,`>I-
MB>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"38G82,'B'DP)\D&)UD@)
MT4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN2<'H&TC!Y@5,"<9$
MC00.3(GF2<'L`DR)\4C!YAY,">9!B?1("?),(>%,(>I("<I(BXPDT`$``$@!
MP4D!RTR)P4@#A"38`0``3`':38G#2,'A!4P!\$G!ZQM,"=F)R4@!RDR)Z4G!
M[0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=2`'P3(G>2<'M&TC!
MY@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,,<$QRDB+C"3@`0``
M2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)V4C!X1Y)P>L"08G4
M20G+3(G!38GF18G`3#'92<'N&S'(2(N,).@!``!(`?%)`<]*C0PX3(G@2,'@
M!4P)\(G`3(TT`4R)Z$G![0),B=E(P>`>18GW18G;20G%2(N$)/`!``!,,>E(
M`?`QRDR)^4P!P$C!Z1M(`<),B?A(P>`%2`G(2(N,)/@!``")P$@!PDR)X$@!
M\4G![`)(P>`>3`'938GK08G03`G@38G$18GM23'#2<'L&T4QWDZ-'#%,B<%(
MP>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0``@``2`'Q3`'I28G%
MB<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)P>@"B=)(P>$>20'5
M2(N4)`@"``!,"<%-B?A),<A%B>Y%B?](`?)%,<-(`=!,B?).C0083(GP2,'J
M&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)"<1(BX0D$`(``$PQ
MXD@!\$$QU4R)VDP!^$D!Q4R)V$C!X`5(P>H;2`G03(GR2<'N`HG`2,'B'DD!
MQ4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(3(GY20'`3(GX2,'I
M&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$)"`"``!,B?%(P>D;
M2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+C"0H`@``B<!)`<1,
MB?A(`?%)P>\"2,'@'D@!RDR)V46)Y4P)^$6)VT@QP4$QR$R)Z4D!T$R)ZDC!
MZ1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+E"0P`@``3(GY2,'I
M&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,B>E)P>T"B=)(P>$>
M20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!,=!,B>))`<!,B>!(
MP>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)Q4D)QTB+A"1``@``
M2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,B>))P>P"B<!(P>(>
M20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](,=&)TD$QR$J-#`!,
MB?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!B<A)"<5(BX0D4`(`
M`$TQ[$@!\$4QXTV)Q$P!^$G![!M)`<-,B<!(P>`%3`G@B<!)`<-,B?!(P>`>
M2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'",=%)C10.3(GA38GF
M2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(2(N,)&`"``!(`?%,
M`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GIB<E)`<M,B>%)P>P"
M2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A,<I(C0P03(GH3(GJ
M2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"``!(`<&)R$@!\DP!
MPDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#2,'H`DG!XQY!`=!,
MB>I)P>T"20G#2(N$)'@"``!(P>(>20G51(GB00';2`'P1`'M3(E?$$@!PDR)
M\$B);QA,,>@QP4B-!`I,B<),B<%%`<A(P>(%2,'I&TR)1PA("<H!T$$!PD0#
M=R!,B1=,B7<@2(N$)(@"``!(,P5=6P``=1)(@<28`@``6UU!7$%=05Y!7\/H
M!,O__P\?0`!(@^P(OX````#H$LO__[J)J\WON?[<NIB^\.'2PTC'``$C16=(
MB5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,`````#'0'@`````2(/$
M",-F9BX/'X0``````)!!5TACPD%628G&055!5$F)_%5)C6PD.%-(B?-(@^P(
M2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P2&-_>(7_=%9!O4``
M``!(B=Y!*?U%.>Y%#T[N2`'O36/]3(GZZ)?-__]!BT0D>$0!Z$&)1"1X@_A`
M=!5(@\0(6UU!7$%=05Y!7\-F#Q]$``!,B>=%*>Y,`?OH\NC__T&#_C\/CMP`
M``!!@^Y`18GW0<'O!D6)_4F#Q0%)P>4&20'=\P]O`TR)YTB#PT`/$44`\P]O
M2]`/$4T0\P]O4^`/$54@\P]O6_`/$5TPZ*#H__],.>MUS$'!YP9%*?Y)8\9(
M@_@(<EM)BU4`28E4)#A)BU0%^$B)5`7X2(U5"$B#XOA(*=5)*>U(`<5(@^7X
M2(/]"'(82(/E^#'`28M,!0!(B0P"2(/`"$@YZ'+N18ET)'A(@\0(6UU!7$%=
M05Y!7\.0J`1U*$B%P'3B00^V50!!B%0D.*@"=-1!#[=4!?YFB50%_NO'28G=
MZ7#___]!BU4`08E4)#A!BU0%_(E4!?SKJT%63(UV.$%505152(G]4TB+1BA(
MB?-$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(F,9$!CB`2&/!3`'P@_DX#XX@
M`0``ND`````IRHG1=`\QTHG6@\(!Q@0P`#G*<O-(B=_HBN?__V8/[\`/$4,X
M2<=&,`````!!#Q%&$$$/$48@1(EK<$B)WT2)8W3H8.?__TB+`TB)WTC!Z!B(
M10!(BP-(P>@0B$4!2(L#2,'H"(A%`DB+`XA%`TB+0PA(P>@8B$4$2(M#"$C!
MZ!"(105(BT,(2,'H"(A%!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)
M2(M#$$C!Z`B(10I(BT,0B$4+2(M#&$C!Z!B(10Q(BT,82,'H$(A%#4B+0QA(
MP>@(B$4.2(M#&(A%#TB+0R!(P>@8B$402(M#($C!Z!"(11%(BT,@2,'H"(A%
M$DB+0R!;B$4374%<05U!7ND\R/__NC@````Q_RG*@_H(<R[VP@1U:X72#X0!
M____Q@``]L("#X3U_O__,<EFB4P0_NGI_O__9@\?A```````B=%(QP``````
M2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"M?[__X/B^#'`B<:#P`A(
MB3PQ.=!R\^F>_O__QP``````QT00_`````#IB_[__TB+!<Q2``!(@_C_="15
M2(GE4TB#[`B[**1``/_02(/K"$B+`TB#^/]U\4B#Q`A;7</#`$B#[`CH8,[_
M_TB#Q`C#````+@`N+@`E<R\E<P`O<')O8R]C=7)P<F]C+V9I;&4`1'EN84QO
M861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`%!!
M4E]414U0`%!!4E]04D]'3D%-10`Z`"\`)7,E<R5S`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?
M4$%42`!54T52`%-94U1%30`O=&UP+P!435!$25(`5$5-4$1)4@!414U0`%1-
M4`!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S)7,`4$%42`!P87)L`"YP87(`
M)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4T`"UE`"TM````
M`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P97)L
M>'-I+F,`````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T
M;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R
M;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E
M<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@
M("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N
M97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3
M,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q
M6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D[
M"F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI
M.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\
M.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F
M:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET
M(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I
M>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM
M>2`D;6%G:6-?<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C
M($Y/5$4Z("1M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?
M<&]S+"`P.PIR96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H
M)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-
M04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G
M:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`[
M"B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D
M(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E
M860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI
M;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA
M;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP
M86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^
M("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V
M95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U
M;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D
M9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%2
M7U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE
M)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB
M*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]
M/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I
M;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I
M;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D
M=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?
M0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@
M=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I
M;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP
M;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64[
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D
M=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E
M<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K
M97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE
M(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92![
M"F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M
M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE
M?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;
M3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O
M9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?
M1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`
M<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N
M86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@
M=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D
M05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D
M:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R
M"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A
M<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS
M:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6
M.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O
M7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),
M8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S
M:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L
M(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R
M7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]
M"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I
M9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@
M97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G
M(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R
M(ET["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@
M)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP
M87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A
M9"!P87(@9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B
M=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A
M=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ
M1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ
M1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A
M=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(
M+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*
M<F5A9"!?1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@
M)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@
M;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY
M("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@
M)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]
M?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG
M=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO
M861E<BD["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D
M9F@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B
M)&YA;64B72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF
M("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T
M,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U
M="DI6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N
M(&UY("1F:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92`D9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C
M86-H95]N86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I
M.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%2
M7T1%0E5'?3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M
M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H
M,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU
M;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N
M(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED
M:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*
M)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS
M=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE
M.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL
M93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U
M:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL
M97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B
M(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,
M;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I
M<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U
M:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R
M=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD
M;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6([
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR
M97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ
M1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S
M.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@
M?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U
M:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4
M:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L
M24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@
M=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD
M<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH
M;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!4
M14U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N
M;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@[
M"FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E
M='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN
M,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D
M<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\
M("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O
M7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA
M;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E
M:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D
M("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@
M(B1S>7-[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T
M(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N
M86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T
M.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE
M+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*
M?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A
M<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY
M("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET
M92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S
M92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D
M93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E
M;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N
M86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6
M>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]
M"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD
M97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA
M;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES
M>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P
M96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H
M.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE
M("X]("1S>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H
M<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X
M="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM0
M05)?5$5-4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P
M<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S
M>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N
M86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI
M;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C
M=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W
M9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD
M<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D
M)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE
M.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,
M25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.
M251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.
M($1%0E5'($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?
M)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF
M(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE
M86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE
M;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V
M86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB
M*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#
M3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*````%``````````!>E(``7@0`1L,
M!PB0`0``3````!P````PC___Q@````!"#A"/`D(.&(X#0@X@C01"#BB,!4$.
M,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+```````D````
M;````+"/__][`````$$.$(,"1PX@`FP*#A!!#@A!"P``````3````)0````(
MD/__-P(```!"#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&1`XX@P='#F`#%0$*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P`````\````Y````/B1__]!`0```$(.
M$(T"0@X8C`-!#B"&!$$.*(,%1P[``7H*#BA!#B!!#AA"#A!"#@A#"P``````
M)````"0!```(D___@0````!!#A"#`DH.H`$";PH.$$$."$$+`````#P```!,
M`0``<)/__\D`````0@X0C0)*#AB,`T$.((8$20XH@P5'#L`(`GH*#BA!#B!!
M#AA"#A!"#@A#"P`````4````C`$```"4__\J`````$0.$&$."``4````I`$`
M`!B4__]$`````$0.$'L."``4````O`$``%"4__\#```````````````\````
MU`$``$B4___/`0```$(.$(T"0@X8C`-)#B"&!$$.*(,%2@[`"0)<"@XH00X@
M00X80@X00@X(1@L`````%````!0"``#8E?__)```````````````+````"P"
M``#PE?__NP````!3#A"#`@)+"L,."$4+=PX(1L-0#A"#`D;##@@`````'```
M`%P"``"`EO__M0$```!$#E`#2@$*#@A""P`````<````?`(``""8__]J````
M`$0.(&L*#@A!"P```````!0```"<`@``<)C__QT`````1`X06`X(`#0```"T
M`@``>)C__[$`````0@X0C`)!#AB&`TD.((,$1`XP`D8*#B!!#AA!#A!"#@A&
M"P``````7````.P"````F?__/`<```!"#A".`D(.&(T#2@X@C`1!#BB&!4$.
M,(,&1PZ0@P(#E`(*#C!!#BA!#B!"#AA"#A!"#@A!"P.K`0Z8@P)+#J"#`EL.
MF(,"00Z0@P(`````+````$P#``#@G___;P(```!!#A"&`D$.&(,#1`XP`[P!
M"@X800X000X(00L`````-````'P#```@HO__=0````!!#A"&`D0.&(,#1`X@
M`EL*#AA!#A!!#@A!"T0.&$0.$$$."``````D````M`,``/B&___L`0```$$.
M$(,"1`Y``X@!"@X000X(00L`````3````-P#``!0HO__#!8```!"#A"/`D8.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`^<5"@XX00XP00XH0@X@0@X8
M0@X00@X(00L````4````+`0``!"X__]4`````$0.$`)/#@AD````1`0``%BX
M__^@`0```$(.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9&#CB#!T<.0`)@"@XX
M00XP00XH0@X@0@X80@X00@X(1PL"Q`H..$$.,$$.*$(.($(.&$(.$$(."$(+
M`````$0```"L!```D+G___4!````0@X0C@)&#AB-`T(.((P$00XHA@5$#C"#
M!@-&`0H.*$0.($(.&$(.$$(."$4+`````````````"0```#T!```V('__^`#
M````#A!&#AA*#PMW"(``/QH[*C,D(@```````````1L#.^#Z__\9````M('_
M_]3___^4A?__E/[__S2*___\^O__!(O__TS[__^$B___=/O__\2-___$^___
M%(___P3\__^DC___+/S__W20__]L_/__I)#__X3\___TD/__G/S__P21__^T
M_/__U)+___3\__\$D___#/W__\23__\\_?__A)7__US]___TE?__?/W__Q26
M__^4_?__U);__\S]__\4GO__+/[__X2@__]<_O__%*'__[S^__\DM___#/__
M_X2W__\D____)+G__XS___\`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````,`````````"*)````````"`````````+@%````````%P``
M```````8$D```````!0`````````!P`````````'`````````*`10```````
M"`````````!X``````````D`````````&``````````5````````````````
M````!@````````!0`D````````L`````````&``````````%`````````"`+
M0```````"@````````"=!````````/7^_V\`````P`]````````!````````
M`!H$`````````0`````````J!`````````$`````````.@0````````!````
M`````$4$`````````0````````!/!`````````$`````````700````````!
M`````````#,`````````#`````````#0%T````````T`````````B%%`````
M```=`````````&H$````````\/__;P````"T$$```````/[__V\`````<!%`
M``````#___]O``````$`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````H$``````````
M```````````````````&&$```````!880```````)AA````````V&$``````
M`$880```````5AA```````!F&$```````'880```````AAA```````"6&$``
M`````*880```````MAA```````#&&$```````-880```````YAA```````#V
M&$````````890```````%AE````````F&4```````#890```````1AE`````
M``!6&4```````&890```````=AE```````"&&4```````)890```````IAE`
M``````"V&4```````,890```````UAE```````#F&4```````/890```````
M!AI````````6&D```````"8:0```````-AI```````!&&D```````%8:0```
M````9AI```````!V&D```````(8:0```````EAI```````"F&D```````+8:
M0```````QAI```````#6&D```````.8:0```````]AI````````&&T``````
M`!8;0```````)AM````````V&T```````$8;0```````5AM```````!F&T``
M`````'8;0```````AAM```````"6&T```````*8;0```````MAM```````#&
M&T```````)A10`````````````````#_____`````,A40```````________
M__\``````````/__________````````````1T-#.B`X+C,@6T1R86=O;D9L
M>5T@4F5L96%S92\R,#$Y+3`R+3(R``````0````)````!````$=.50!G;VQD
M(#$N,38`````+G1E>'0`+F=O=``N8V]M;65N=``N9V]T+G!L=``N<F5L82YP
M;'0`+FEN:70`+F)S<P`N9'1O<G,`+F-T;W)S`"YD>6YS='(`+F5H7V9R86UE
M7VAD<@`N9VYU+G9E<G-I;VY?<@`N:6YT97)P`"YR96QA+F1Y;@`N9VYU+G9E
M<G-I;VX`+FYO=&4N9VYU+F=O;&0M=F5R<VEO;@`N9'EN<WEM`"YF:6YI`"YG
M;G4N:&%S:``N;F]T92YT86<`+F5H7V9R86UE`"YT;5]C;&]N95]T86)L90`N
M9'EN86UI8P`N<VAS=')T86(`+G)O9&%T80`N9&%T80``````````````````
M````````````````````````````````````````````````````````````
M`````````````````&8````!`````@```````````D`````````"````````
M%0````````````````````$```````````````````"T````!P````(`````
M````&`)````````8`@```````#@````````````````````$````````````
M````````G`````L````"`````````%`"0```````4`(```````#0"```````
M``0````!````"``````````8`````````$$````#`````@`````````@"T``
M`````"`+````````G00```````````````````$```````````````````"J
M````]O__;P(`````````P`]```````#`#P```````/0``````````P``````
M```(````````````````````>````/___V\"`````````+000```````M!``
M``````"\``````````,``````````@`````````"`````````%<```#^__]O
M`@````````!P$4```````'`1````````,``````````$`````0````0`````
M``````````````!N````!`````(`````````H!%```````"@$0```````'@`
M`````````P`````````(`````````!@`````````'@````0```!"````````
M`!@20```````&!(```````"X!0````````,````+````"``````````8````
M`````"@````!````!@````````#0%T```````-`7````````$P``````````
M``````````0````````````````````C`````0````8`````````\!=`````
M``#P%P```````.`#```````````````````0`````````!```````````0``
M``$````&`````````-`;0```````T!L```````"W-0``````````````````
M$````````````````````*0````!````!@````````"(44```````(A1````
M````#@````````````````````0```````````````````#K`````0````(`
M````````F%%```````"840```````(8_```````````````````(````````
M````````````O@````$``'`"`````````""10```````()$````````<!0``
M````````````````"````````````````````$D````!``!P`@`````````\
MED```````#R6````````U`````````````````````0`````````````````
M``#8````!@````,``````````*!`````````H``````````"````````!```
M```````(`````````!``````````!P````$````#``````````"B0```````
M`*(````````(````````````````````"````````````````````!4````!
M`````P`````````(HD````````BB``````````(```````````````````@`
M``````````````````#S`````0````,`````````"*1````````(I```````
M`"`````````````````````(````````````````````.@````$````#````
M`````"BD0```````**0````````0````````````````````"```````````
M`````````#,````!`````P`````````XI$```````#BD````````$```````
M``````````````@```````````````````#(`````0````,`````````2*1`
M``````!(I``````````````````````````````(````````````````````
M+@````@````#`````````&"D0```````2*0```````"A!```````````````
M````(`````````````````````P````!````,````````````````````$BD
M````````*0````````````````````$``````````0````````"%````!P``
M``````````````````````!TI````````!P````````````````````$````
M````````````````X0````,`````````````````````````D*0```````#Y
?`````````````````````0``````````````````````
